@@ -5,18 +5,15 @@ from spider.param import *
 # from spider import motion_planning, path_planning
 # from spider import planner_zoo
 # from spider import RL
-
-
-# import spider.teaser as teaser
-
+from spider.teaser import teaser
 
 
 submodules = [
     'elements', 'utils', 'sampler', 'evaluator', 'interface', 'vehicle_model', 'planner_zoo', 'RL',
-    'teaser', 'param'
+    #'teaser', 'param'
 ]
 
-__all__ = submodules
+__all__ = submodules + ['teaser', 'param']
 
 
 def __dir__():
