@@ -29,10 +29,9 @@ class LatticePlanner(BasePlanner):
     def __init__(self, config=None):
         super(LatticePlanner, self).__init__(config)
 
-        self.config = self.default_config()
-        if not (config is None):
-            self.config.update(config)
-            # self.configure(config)
+        # self.config = self.default_config() # 已经在base planner中继承
+        # if not (config is None):
+        #     self.config.update(config)
 
         self.local_map = RoutedLocalMap()
         self.coordinate_transformer = FrenetCoordinateTransformer() # 要维护几个坐标系呢？
@@ -60,8 +59,8 @@ class LatticePlanner(BasePlanner):
         """
         return {
             "output": spider.OUTPUT_TRAJECTORY,
-            "steps": 50,
-            "dt": 0.1,
+            "steps": 20,
+            "dt": 0.2,
             "ego_veh_length": 5.0,
             "ego_veh_width": 2.0,
             "max_speed": 65/3.6,
@@ -70,9 +69,9 @@ class LatticePlanner(BasePlanner):
             "max_deceleration": 10,
             # "max_centripetal_acceleration" : 100,
             "max_curvature": 100,
-            "safe_distance": (1.0, 0.2),
+            "safe_distance": (1.0, 0.2),  # 目前好像还没用
             "end_s_candidates": (10,20,40,60),
-            "end_l_candidates": (-0.8,0,0.8), # s,d采样生成横向轨迹 (-3.5, 0, 3.5), #
+            "end_l_candidates": (-3.5, 0, 3.5),# (-0.8,0,0.8), # s,d采样生成横向轨迹 (-3.5, 0, 3.5), #
             "end_v_candidates": tuple(i*60/3.6/3 for i in range(4)), # 改这一项的时候，要连着限速一起改了
             "end_T_candidates": (1,2,4,8), # s_dot, T采样生成纵向轨迹
 
@@ -87,18 +86,6 @@ class LatticePlanner(BasePlanner):
             },
         }
 
-    def configure(self, config: dict):
-        self.__init__(config)
-        # if config:
-            # self.config.update(config)
-        # self.speed_bound = [self.config["min_speed"], self.config["max_speed"]]
-        # self.acc_bound = [-self.config["max_deceleration"], self.config["max_acceleration"]]
-        # self.max_curvature = self.config["max_curvature"]
-        # self.end_s_candidates = self.config["end_s_candidates"]
-        # self.end_d_candidates = self.config["end_d_candidates"]
-        # self.end_v_candidates = self.config["end_v_candidates"]
-        # self.end_T_candidates = self.config["end_T_candidates"]
-
 
     def get_candidate_traj_with_cost(self):
         return self._candidate_trajectories, self._candidate_trajectories_cost
@@ -238,8 +225,7 @@ if __name__ == '__main__':
         tb_list.append(TrackingBox(obb=(50, 0, 5, 2, 0), vx=0, vy=0))
         tb_list.append(TrackingBox(obb=(100, 0, 5, 2, 0), vx=0, vy=0))
 
-        lattice_planner = LatticePlanner()
-        lattice_planner.configure({"end_l_candidates": (-3.5, 0, 3.5)})
+        lattice_planner = LatticePlanner({"end_l_candidates": (-3.5, 0, 3.5)})
         lattice_planner.set_local_map(local_map)
 
         save_video = True
@@ -338,8 +324,7 @@ if __name__ == '__main__':
         tb_list = TrackingBoxList()
         tb_list.append(TrackingBox(obb=(-3.5/2, 20, 5, 2, -math.pi/2), vx=0, vy=-5))
 
-        lattice_planner = LatticePlanner()
-        lattice_planner.configure({
+        lattice_planner = LatticePlanner({
             "end_l_candidates": (-0.8, 0, 0.8),
             "steps": 20,
             "max_speed": 30/3.6,
