@@ -1,7 +1,10 @@
-from spider.planner_zoo.BasePlanner import BasePlanner
+from spider.planner_zoo.BasePlanner import BasePlanner, DummyPlanner
 from spider.planner_zoo.LatticePlanner import LatticePlanner
 # from spider.planner_zoo.MFRLPlanner import MFRLPlanner
 from spider.planner_zoo.BezierPlanner import BezierPlanner
 from spider.planner_zoo.PiecewiseLatticePlanner import PiecewiseLatticePlanner
 from spider.planner_zoo.ImaginaryPlanner import ImaginaryPlanner
+from spider.planner_zoo.OptimizedLatticePlanner import OptimizedLatticePlanner
+from spider.planner_zoo.FallbackPlanner import FallbackPlanner
+
 
